Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(469)

Unified Diff: components/payments/core/journey_logger.h

Issue 2790253002: [Payments] Don't record CanMakePayment when in incognito mode. (Closed)
Patch Set: Pass in constructor Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/payments/core/journey_logger.h
diff --git a/components/payments/core/journey_logger.h b/components/payments/core/journey_logger.h
index 5c35c0d7ecfa3015fcc4fd653f6d092183858a6d..f2574735319eb415275a1b16932f5c2784332db9 100644
--- a/components/payments/core/journey_logger.h
+++ b/components/payments/core/journey_logger.h
@@ -53,7 +53,7 @@ class JourneyLogger {
static const int CMP_SHOW_COULD_MAKE_PAYMENT_ = 1 << 1;
static const int CMP_SHOW_MAX = 4;
- JourneyLogger();
+ JourneyLogger(bool is_incognito);
~JourneyLogger();
// Increments the number of selection adds for the specified section.
@@ -112,7 +112,8 @@ class JourneyLogger {
// merchant.
void RecordSectionSpecificStats(CompletionStatus completion_status);
// Records the metrics related the the CanMakePayment method.
void RecordCanMakePaymentStats(CompletionStatus completion_status);
// Records CanMakePayment's return value effect on whether the Payment Request
@@ -128,6 +129,7 @@ class JourneyLogger {
bool was_can_make_payments_used_;
bool could_make_payment_;
bool was_show_called_;
+ bool is_incognito_;
DISALLOW_COPY_AND_ASSIGN(JourneyLogger);
};
@@ -112,7 +112,8 @@ class JourneyLogger {
// merchant.
void RecordSectionSpecificStats(CompletionStatus completion_status);
- // Records the metrics related the the CanMakePayment method.
+ // Records the metrics related the the CanMakePayment method, if the Payment
+ // Request was not done in an incognito tab.
void RecordCanMakePaymentStats(CompletionStatus completion_status);
// Records CanMakePayment's return value effect on whether the Payment Request

Powered by Google App Engine
This is Rietveld 408576698